cosmetic: use proper name for SMPP handlers

Change-Id: I0d714e927e287a0ea9362008ed050a492510e22b
diff --git a/include/osmocom/smpp/smpp.h b/include/osmocom/smpp/smpp.h
index 54e5de7..a2832d3 100644
--- a/include/osmocom/smpp/smpp.h
+++ b/include/osmocom/smpp/smpp.h
@@ -51,5 +51,5 @@
 uint32_t smpp_msgb_cmdid(struct msgb *msg);
 uint32_t esme_inc_seq_nr(struct esme *esme);
 int pack_and_send(struct esme *esme, uint32_t type, void *ptr);
-int smpp_openbsc_alloc_init(void *ctx);
-int smpp_openbsc_start(struct gsm_network *net);
+int smpp_msc_alloc_init(void *ctx);
+int smpp_msc_start(struct gsm_network *net);
diff --git a/src/osmo-msc/msc_main.c b/src/osmo-msc/msc_main.c
index 4ef5948..9cc4120 100644
--- a/src/osmo-msc/msc_main.c
+++ b/src/osmo-msc/msc_main.c
@@ -608,7 +608,7 @@
 	}
 
 #ifdef BUILD_SMPP
-	if (smpp_openbsc_alloc_init(tall_msc_ctx) < 0)
+	if (smpp_msc_alloc_init(tall_msc_ctx) < 0)
 		return -1;
 #endif
 	sgs_iface_init(tall_msc_ctx, msc_network);
@@ -652,7 +652,7 @@
 	 * following code until iu_init() is legacy. */
 
 #ifdef BUILD_SMPP
-	smpp_openbsc_start(msc_network);
+	smpp_msc_start(msc_network);
 #endif
 
 	/* start control interface after reading config for
diff --git a/src/libsmpputil/smpp_msc.c b/src/libsmpputil/smpp_msc.c
index 1e0ccdd..4a980ab 100644
--- a/src/libsmpputil/smpp_msc.c
+++ b/src/libsmpputil/smpp_msc.c
@@ -824,8 +824,8 @@
 	return g_smsc;
 }
 
-/*! \brief Allocate the OpenBSC SMPP interface struct and init VTY. */
-int smpp_openbsc_alloc_init(void *ctx)
+/*! \brief Allocate the OsmoMSC SMPP interface struct and init VTY. */
+int smpp_msc_alloc_init(void *ctx)
 {
 	g_smsc = smpp_smsc_alloc_init(ctx);
 	if (!g_smsc) {
@@ -836,9 +836,9 @@
 	return smpp_vty_init();
 }
 
 /*! \brief Launch the OpenBSC SMPP interface with the parameters set from VTY.
  */
-int smpp_openbsc_start(struct gsm_network *net)
+int smpp_msc_start(struct gsm_network *net)
 {
 	int rc;
 	g_smsc->priv = net;
@@ -836,9 +836,9 @@
 }
 
-/*! \brief Launch the OpenBSC SMPP interface with the parameters set from VTY.
+/*! \brief Launch the OsmoMSC SMPP interface with the parameters set from VTY.
  */